==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_toroko_house.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",42,8)
end


--询问马宾去向
function AskEveryoneWhereMahinWent()
    KEY()HMC()
    FAI(2)
    FAC("sue_normal")MS3("今天我在村子外边\n看到了一只巨大的猫...")NOD()
    WAI(32)
    --桑塔开门进来
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    SLR(1)
    SMC()
    WAI(32)CLO()
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    --多隆子看左边
    ANP("Toroko1",0,0)
    WAI(32)
    FAC("toroko_><")
    MS4("\n是间八哥！")NOD()CLR()
    FAC("sue_normal")
    CAT("你在找那个胖咪咪卡嘛？")NOD()
    CAT("\n胖咪咪卡的话")
    CAT("\n今天没有看到他诶，")NOD()
    FAC("sue_sad")CAT("\n不过昨天大家一起吃饭的时候")
    CAT("\n感觉他心情有点低落。")NOD()CLR()
    FAC("sue_angry")CAT("大概是他吃鱼吃腻了")NOD()
    CAT("\n然后出去找果子吃了吧...")NOD()CLR()
    FAC("toroko_normal")MS3("\n多隆子也觉得是这样！")NOD()CLR()
    FAC("sue_normal")CAT("总之不用担心他啦，")NOD()
    CAT("\n过几天他就会回来了。")NOD()CLR()
    FAC("toroko_><")
    MS3("嗯嗯！")NOD()
    CAT("\n间八哥再等等看吧~")NOD()CLO()
    --离开屋子
    FLS("GoTorokoHome")
    FLP("AskedToroko")
    FAO(0)
    SMC()
    if(FLJ("AskedJack")) then
        FLP("Night")
        MSR("AskEveryoneAboutMahin","GoHomeSleep")
        TRA("CS_village_night","E0090",42,8)
    else
        TRA("CS_village","E0090",42,8)
    end
end

--经验胶囊（数）
function SueGiveExp()
    FLS("SueGiveExp")
end
--经验胶囊（多隆子）
function TorokoGiveExp()
    FLS("TorokoGiveExp")
end

function KingBack()
    KEY()
    --增加金
    SGP("CS_mychar_king",15,16,1,"CS_mychar_king_p1")
    SPL(0,"CS_mychar_king_p1")--让玩家1控制金
    FLP("KingBack")
    ITS()--清空所有物品
    ITP("Sword")--带上枪
    HMC(0)
    SLR(1,0)
    FAI(2)
    FAC("king_normal")MS3("\n孩子们我回来了。")NOD()CLO()
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    AMC("walk")
    WAI(5*16)
    AMC("normal")
    WAI(32)
    AMC("normal",0)
    WAI(32)
    AMC("normal",1)
    WAI(32)
    FAC("king_normal")MS3("\n是跑出去玩了嘛...")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_village","KingBack",32,14)
end

==> ocstore25_10_6.zip: OcStore/Prgm/data/map/CS_toroko_house.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",42,8)
end


--询问马宾去向
function AskEveryoneWhereMahinWent()
    KEY()HMC()
    FAI(2)
    FAC("sue_normal")MS3("今天我在村子外边")
    CAT("\n看到了一只巨大的猫...")NOD()
    WAI(32)
    --桑塔开门进来
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    SLR(1)
    SMC()
    WAI(32)CLO()
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    --多隆子看左边
    ANP("Toroko1",0,0)
    WAI(32)
    FAC("toroko_><")
    MS4("\n是间八哥！")NOD()CLR()
    FAC("sue_normal")
    CAT("你在找那个胖咪咪卡嘛？")NOD()
    CAT("\n胖咪咪卡的话")
    CAT("\n今天没有看到他诶，")NOD()
    FAC("sue_sad")CAT("\n不过昨天大家一起吃饭的时候")
    CAT("\n感觉他心情有点低落。")NOD()CLR()
    FAC("sue_angry")CAT("大概是他吃鱼吃腻了")NOD()
    CAT("\n然后出去找果子吃了吧...")NOD()CLR()
    FAC("toroko_normal")MS3("\n多隆子也觉得是这样！")NOD()CLR()
    FAC("sue_normal")CAT("总之不用担心他啦，")NOD()
    CAT("\n过几天他就会回来了。")NOD()CLR()
    FAC("toroko_><")
    MS3("嗯嗯！")NOD()
    CAT("\n间八哥再等等看吧~")NOD()CLO()
    --离开屋子
    FLS("GoTorokoHome")
    FLP("AskedToroko")
    FAO(0)
    SMC()
    if(FLJ("AskedJack")) then
        FLP("Night")
        MSR("AskEveryoneAboutMahin","GoHomeSleep")
        TRA("CS_village_night","E0090",42,8)
    else
        TRA("CS_village","E0090",42,8)
    end
end

--经验胶囊（数）
function SueGiveExp()
    FLS("SueGiveExp")
end
--经验胶囊（多隆子）
function TorokoGiveExp()
    FLS("TorokoGiveExp")
end

function KingBack()
    KEY()
    --增加金
    SGP("CS_mychar_king",15,16,1,"CS_mychar_king_p1")
    SPL(0,"CS_mychar_king_p1")--让玩家1控制金
    FLP("KingBack")
    ITS()--清空所有物品
    ITP("Sword")--带上枪
    HMC(0)
    SLR(1,0)
    FAI(2)
    FAC("king_normal")MS3("\n孩子们我回来了。")NOD()CLO()
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    AMC("walk")
    WAI(5*16)
    AMC("normal")
    WAI(32)
    AMC("normal",0)
    WAI(32)
    AMC("normal",1)
    WAI(32)
    FAC("king_normal")MS3("\n是跑出去玩了嘛...")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_village","KingBack",32,14)
end
